MethodChannelFlutterCryptoAlgorithm class

An implementation of FlutterCryptoAlgorithmPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(String value, String privateKey, String? ivKey) → Future<String?>
override
encrypt(String value, String privateKey, String? ivKey) → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited